@@ -541,7 +541,7 @@ e_cal_backend_sync_set_default_zone (ECalBackendSync *backend, EDataCal *cal, co
 
 		if (icalcomp) {
 			icaltimezone_set_component (zone, icalcomp);
-			tzid = icaltimezone_get_tzid (zone);
+			tzid = g_strdup (icaltimezone_get_tzid (zone));
 		}
 
 		icaltimezone_free (zone, 1);
@@ -764,7 +764,6 @@ _e_cal_backend_remove_object (ECalBackend *backend, EDataCal *cal, const char *u
 	status = e_cal_backend_sync_remove_object (E_CAL_BACKEND_SYNC (backend), cal, uid, rid, mod, &old_object, &object);
 
 	if (status == GNOME_Evolution_Calendar_Success) {
-		char *calobj = NULL;
 
 		ECalComponentId *id = g_new0 (ECalComponentId, 1);
 		id->uid = g_strdup (uid);
