@@ -32,6 +32,7 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
+#include <libedataserver/e-data-server-util.h>
 #include "camel/camel-exception.h"
 #include "camel/camel-file-utils.h"
 #include "camel/camel-i18n.h"
@@ -174,7 +175,7 @@ get_folder(CamelStore * store, const char *folder_name, guint32 flags, CamelExce
 	}
 	
 	/* need to create the dir heirarchy */
-	if (camel_mkdir (path, 0777) == -1 && errno != EEXIST) {
+	if (e_util_mkdir_hier (path, 0777) == -1 && errno != EEXIST) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_STORE_NO_FOLDER,
 				      _("Cannot get folder: %s: %s"),
 				      path, g_strerror (errno));
@@ -261,7 +262,7 @@ create_folder(CamelStore *store, const char *parent_name, const char *folder_nam
 
 	/* This is a pretty hacky version of create folder, but should basically work */
 
-	if (g_path_is_absolute(path)) {
+	if (!g_path_is_absolute(path)) {
 		camel_exception_setv(ex, CAMEL_EXCEPTION_STORE_NO_FOLDER,
 				     _("Store root %s is not an absolute path"), path);
 		return NULL;
@@ -305,8 +306,8 @@ create_folder(CamelStore *store, const char *parent_name, const char *folder_nam
 static int xrename(const char *oldp, const char *newp, const char *prefix, const char *suffix, int missingok, CamelException *ex)
 {
 	struct stat st;
-	char *old = g_strconcat(prefix, oldp, suffix, 0);
-	char *new = g_strconcat(prefix, newp, suffix, 0);
+	char *old = g_strconcat(prefix, oldp, suffix, NULL);
+	char *new = g_strconcat(prefix, newp, suffix, NULL);
 	int ret = -1;
 	int err = 0;
 
