@@ -54,7 +54,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#define d(x) x
+#define d(x)
 #define ADS_UF_DONT_EXPIRE_PASSWORD 0x10000
 #define ONE_HUNDRED_NANOSECOND 0.000000100
 #define SECONDS_IN_DAY 86400
@@ -527,6 +527,8 @@ exchange_account_remove_folder (ExchangeAccount *account, const char *path)
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), 
 				EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
 
+	d(g_print ("exchange_account_remove_folder: path=[%s]\n", path));
+
 	if (!get_folder (account, path, &folder, &hier))
 		return EXCHANGE_ACCOUNT_FOLDER_DOES_NOT_EXIST;
 
@@ -672,7 +674,7 @@ exchange_account_discover_shared_folder (ExchangeAccount *account,
 				EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
 
 	if (!account->priv->gc)
-		return EXCHANGE_ACCOUNT_FOLDER_UNSUPPORTED_OPERATION;
+		return EXCHANGE_ACCOUNT_FOLDER_GC_NOTREACHABLE;
 
 	email = strchr (user, '<');
 	if (email)
@@ -709,9 +711,12 @@ exchange_account_discover_shared_folder (ExchangeAccount *account,
 	g_mutex_unlock (account->priv->discover_data_lock);
 
 	if (status != E2K_GLOBAL_CATALOG_OK) {
-		return (status == E2K_GLOBAL_CATALOG_ERROR) ?
-			EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR :
-			EXCHANGE_ACCOUNT_FOLDER_DOES_NOT_EXIST;
+		if (status == E2K_GLOBAL_CATALOG_ERROR)
+			return EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR;
+		if (status == E2K_GLOBAL_CATALOG_NO_SUCH_USER)
+			return EXCHANGE_ACCOUNT_FOLDER_NO_SUCH_USER;
+		else
+			return EXCHANGE_ACCOUNT_FOLDER_DOES_NOT_EXIST;
 	}
 
 	hier = get_hierarchy_for (account, entry);
@@ -1242,6 +1247,7 @@ setup_account_hierarchies (ExchangeAccount *account)
 					      account->priv->identity_email,
 					      account->priv->source_uri,
 					      TRUE);
+
 	setup_hierarchy (account, hier);
 	g_free (phys_uri_prefix);
 
@@ -1860,6 +1866,22 @@ exchange_account_get_username (ExchangeAccount *account)
 	return account->priv->username;
 }
 
+/**
+  * exchange_account_get_email_id :
+  * @account : #ExchangeAccount
+  *
+  * Retunrs user's e-mail id. 
+  *
+  * Return value : e-mail id string.
+  **/
+char *
+exchange_account_get_email_id (ExchangeAccount *account)
+{
+	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), NULL);
+
+	return account->priv->identity_email;
+} 
+
 /**
   * exchange_account_folder_size_add :
   * @account : #ExchangeAccount
@@ -1984,6 +2006,8 @@ exchange_account_new (EAccountList *account_list, EAccount *adata)
 	}
 
 	account = g_object_new (EXCHANGE_TYPE_ACCOUNT, NULL);
+	if (!account)
+		return NULL;
 	account->priv->account_list = account_list;
 	g_object_ref (account_list);
 	account->priv->account = adata;
